@@ -17,7 +17,7 @@
 import sys
 from calculate.lib.cl_xml import xpath
 import xml.dom.minidom
-from calculate.lib.utils.common import _error
+from calculate.lib.cl_template import TemplateFormat
 from calculate.lib.cl_lang import setLocalTranslate
 from collections import Iterable
 
@@ -25,7 +25,7 @@ _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
 
-class xml_xfce(_error):
+class xml_xfce(TemplateFormat):
     """Класс для объединения xfce-xml файлов"""
     # root нода
     rootNode = False
@@ -38,10 +38,6 @@ class xml_xfce(_error):
     # Комментарий
     _comment = ("<!--", "-->")
 
-    def __init__(self, text):
-        self.text = text
-        self.prepare()
-
     def prepare(self):
         # Создаем пустой объект
         self.docObj = type("_empty_class", (object,), {})()
