@@ -197,7 +197,7 @@ def getInstalledAtom(str_atom, prefix='/'):
 
 def getSquashList():
     """Get supprted squashfs compressions method"""
-    wantMethod = {"lzo", "lzma", "xz", "gzip"}
+    wantMethod = {"lzo", "lzma", "xz", "gzip", "zstd"}
     squashfs_tools = "sys-fs/squashfs-tools"
     usesSquashFs = getPkgActiveUses(squashfs_tools)
     if not usesSquashFs:
